@@ -9,15 +9,17 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1995-2003 Insecure.Com LLC. This       *
- * program is free software; you may redistribute and/or modify it under   *
- * the terms of the GNU General Public License as published by the Free    *
+ * The Nmap Security Scanner is (C) 1996-2004 Insecure.Com LLC. Nmap       *
+ * is also a registered trademark of Insecure.Com LLC.  This program is    *
+ * free software; you may redistribute and/or modify it under the          *
+ * terms of the GNU General Public License as published by the Free        *
  * Software Foundation; Version 2.  This guarantees your right to use,     *
  * modify, and redistribute this software under certain conditions.  If    *
  * you wish to embed Nmap technology into proprietary software, we may be  *
  * willing to sell alternative licenses (contact sales@insecure.com).      *
- * Many security scanner vendors already license Nmap technology such as   *
- * our remote OS fingerprinting database and code.                         *
+ * Many security scanner vendors already license Nmap technology such as  *
+ * our remote OS fingerprinting database and code, service/version         *
+ * detection system, and port scanning code.                               *
  *                                                                         *
  * Note that the GPL places important restrictions on "derived works", yet *
  * it does not provide a detailed definition of that term.  To avoid       *
@@ -86,7 +88,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: output.h,v 1.11 2003/09/11 02:12:57 fyodor Exp $ */
+/* $Id: output.h,v 1.14 2004/04/19 02:02:23 fyodor Exp $ */
 
 #ifndef OUTPUT_H
 #define OUTPUT_H
@@ -113,6 +115,11 @@
    should write helper functions to handle the table creation */
 void printportoutput(Target *currenths, PortList *plist);
 
+/* Prints the MAC address if one was found for the target (generally
+   this means that the target is directly connected on an ethernet
+   network. */
+void printmacinfo(Target *currenths);
+
 /* Write some information (printf style args) to the given log stream(s).
    Remember to watch out for format string bugs. */
 void log_write(int logt, const char *fmt, ...)
